@@ -11,7 +11,7 @@
 #' @param achro should a point be plotted at the origin (defaults to \code{TRUE})?
 #' @param achrosize size of the point at the origin when \code{achro = TRUE} (defaults to \code{0.8}).
 #' @param achrocol color of the point at the origin \code{achro = TRUE} (defaults to \code{'grey'}).
-#' @param lab.cex character expansion factor for category labels when \code{labels = TRUE}).
+#' @param labels.cex character expansion factor for category labels when \code{labels = TRUE}).
 #' @param tick.loc a numeric vector specifying the location of tick marks on x & y axes.
 #' @param margins margins for the plot.
 #' @param square logical. Should the aspect ratio of the plot be held to 1:1? 
@@ -35,7 +35,7 @@
 #' @references Backhaus W. (1991). Color opponent coding in the visual system
 #'  of the honeybee. Vision Research, 31, 1381-1397.
 
-cocplot <- function(cocdata, labels = TRUE, lab.cex = 0.9, 
+cocplot <- function(cocdata, labels = TRUE, labels.cex = 0.9, 
                     tick.loc = c(-12, -9, -6, -3, 3, 6, 9, 12), 
                     achro = FALSE, achrosize = 0.8, achrocol = 'grey',
                     margins = c(1,1,2,2), square=TRUE, ...){ 
@@ -82,8 +82,8 @@ cocplot <- function(cocdata, labels = TRUE, lab.cex = 0.9,
   
   # Category labels (todo: make this more flexible/robust?)
   if(labels == TRUE){
-    text('B', x = 0, y = 13.5, xpd = TRUE, cex = lab.cex)
-    text('A', x = 13.5, y = 0, xpd = TRUE, cex = lab.cex)
+    text('B', x = 0, y = 13.5, xpd = TRUE, cex = labels.cex)
+    text('A', x = 13.5, y = 0, xpd = TRUE, cex = labels.cex)
   }
   
 }
\ No newline at end of file
